local StoneGateV6 = ...

-- Apply building asset processor
StoneGateV6:registerAssetProcessor("models/basic/basicSmallGate.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register Aligned Small Gate materials
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Materials/redRoof", StoneGateSetPrefix .. "_SGATE_RED_ROOF_MATERIAL")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Materials/blueRoof", StoneGateSetPrefix .. "_SGATE_BLUE_ROOF_MATERIAL")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Materials/brownRoof", StoneGateSetPrefix .. "_SGATE_BROWN_ROOF_MATERIAL")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Materials/greyRoof", StoneGateSetPrefix .. "_SGATE_GREY_ROOF_MATERIAL")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Materials/grey2Roof", StoneGateSetPrefix .. "_SGATE_GREY2_ROOF_MATERIAL")


-- Register Aligned Small Gate prefab nodes
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_0_SGate_RootPart", StoneGateSetPrefix .. "_SGATE_ROOT_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_0_SGate_RootPart/Pillar1_SGate_Part", StoneGateSetPrefix .. "_SGATE_PILLAR1_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_0_SGate_RootPart/Pillar2_SGate_Part", StoneGateSetPrefix .. "_SGATE_PILLAR2_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_1_SGate_Tiling1Part", StoneGateSetPrefix .. "_SGATE_TILING1_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_1_SGate_Tiling2Part", StoneGateSetPrefix .. "_SGATE_TILING2_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_1_SGate_Tiling3Part", StoneGateSetPrefix .. "_SGATE_TILING3_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_1_SGate_ext_Tiling1Part", StoneGateSetPrefix .. "_SGATE_EXT_TILING1_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_RootBPart", StoneGateSetPrefix .. "_SGATE_ROOTB_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling1BPart", StoneGateSetPrefix .. "_SGATE_TILING1B_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling1BEPart", StoneGateSetPrefix .. "_SGATE_TILING1BE_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling2BPart", StoneGateSetPrefix .. "_SGATE_TILING2B_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling3BPart", StoneGateSetPrefix .. "_SGATE_TILING3B_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling1BPPart", StoneGateSetPrefix .. "_SGATE_TILING1BP_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling1BEPPart", StoneGateSetPrefix .. "_SGATE_TILING1BEP_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling2BPPart", StoneGateSetPrefix .. "_SGATE_TILING2BP_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_2_SGate_Tiling3BPPart", StoneGateSetPrefix .. "_SGATE_TILING3BP_PREFAB")
StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_3_SGate_TopPart", StoneGateSetPrefix .. "_SGATE_TOP_PREFAB")
--------------------------------------------------------------------------

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	StoneGateV6:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		    },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		    }
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	    }
	})
end

local defaultNodePrefixList = {
        StoneGateSetPrefix .. "_SGATE_PILLAR1",
        StoneGateSetPrefix .. "_SGATE_PILLAR2",
	StoneGateSetPrefix .. "_SGATE_TOP",
	StoneGateSetPrefix .. "_SGATE_TILING1",
	StoneGateSetPrefix .. "_SGATE_TILING2",
	StoneGateSetPrefix .. "_SGATE_TILING3",
	StoneGateSetPrefix .. "_SGATE_EXT_TILING1",
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

function registerAlignedSmallGate(_option)
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_SGATE_TILING1B" .. _option)
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_SGATE_TILING1BE" .. _option)
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_SGATE_TILING2B" .. _option)
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_SGATE_TILING3B" .. _option)
   
    -- Register the stone gate set small gate root part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_SGATE_ROOT" .. _option .. "_PART",
	Name = StoneGateSetPrefix .. "_SGATE_ROOT" .. _option .. "_NAME",
	Description = StoneGateSetPrefix .. "_SGATE_ROOT" .. _option .. "_DESC",
	Category = "CORE",
        BuildingZone = _AlignedSmallGateBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = StoneGateSetPrefix .. "_SGATE_ROOT_PREFAB",
		EndPart = StoneGateSetPrefix .. "_SGATE_ROOTB" .. _option .. "_PART", -- StoneGateSetPrefix .. "_SGATE_ROOTB_PART",
		FillerList = {
			StoneGateSetPrefix .. "_SGATE_TILING1B" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING3_PART",
			StoneGateSetPrefix .. "_SGATE_TILING2_PART",
			StoneGateSetPrefix .. "_SGATE_TILING3_PART",
			StoneGateSetPrefix .. "_SGATE_TILING2_PART"
                },
		BasementFillerList = {
			StoneGateSetPrefix .. "_SGATE_TILING1_PART"
         	},
		MinimumScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
    })


    -- Register the stone gate set small gate root upper part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_SGATE_ROOTB" .. _option .. "_PART",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = StoneGateSetPrefix .. "_SGATE_ROOTB_PREFAB",
		EndPart = StoneGateSetPrefix .. "_SGATE_TOP_PART",
		FillerList = {
			StoneGateSetPrefix .. "_SGATE_TILING3B" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING2B" .. _option .. "_PART"
                },
		MinimumScale = 0,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
    })

    -- Register the stone gate set small gate extension root part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_SGATE_EXT_ROOT" .. _option .. "_PART",
	Name = StoneGateSetPrefix .. "_SGATE_EXT_ROOT" .. _option .. "_NAME",
	Description = StoneGateSetPrefix .. "_SGATE_EXT_ROOT" .. _option .. "_DESC",
	Category = "CORE",
        BuildingZone = _AlignedSmallGateExtensionBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = StoneGateSetPrefix .. "_SGATE_ROOT_PREFAB",
		EndPart = StoneGateSetPrefix .. "_SGATE_ROOTB" .. _option .. "_PART",
		FillerList = {
			StoneGateSetPrefix .. "_SGATE_TILING1BE" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING3B" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING2B" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING3B" .. _option .. "_PART",
			StoneGateSetPrefix .. "_SGATE_TILING2B" .. _option .. "_PART"
                },
		BasementFillerList = {
			StoneGateSetPrefix .. "_SGATE_EXT_TILING1_PART"
         	},
		MinimumScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	}
    })
end

registerAlignedSmallGate("") -- with stone floor
registerAlignedSmallGate("P") -- with wooden floor

--------------------------------------------------------------------------
-- Register flag assigner component on the collider's type to 'PLATFORM'

--StoneGateV6:configurePrefabFlagList("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_3_SGate_TopPart", { "PLATFORM" })
 
-- Register grass clearing components

StoneGateV6:registerPrefabComponent("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_0_SGate_RootPart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = { 4, 8 }
})

function registerRampartPart(_nameFbx, _nameAsset, _attachType)
    StoneGateV6:registerAssetId("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_4_SGate_" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_SGATE_" .. _nameAsset .. "_PREFAB")

-- Register the stone gate set decoration rampart part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_SGATE_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_SGATE_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_SGATE_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_SGATE_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	}
    })

    StoneGateV6:registerPrefabComponent("models/basic/basicSmallGate.fbx/Prefab/smallGate/step_4_SGate_" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = _attachType
    })
end

registerRampartPart( "RampartA", "RAMPART_A", "MAJOR" )
registerRampartPart( "RampartClosingL", "RAMPART_CLOSING_L", "MINOR" )
registerRampartPart( "RampartClosingR", "RAMPART_CLOSING_R", "MINOR" )
registerRampartPart( "HalfRoof", "HALF_ROOF", "MAJOR" )
registerRampartPart( "HalfRoofP", "HALF_ROOFP", "MAJOR" )

