local StoneGateV6 = ...

function registerFbxMaterial(_nameFbxFile, _nameAsset)
    -- Apply building asset processor
    StoneGateV6:registerAssetProcessor("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })

    -- Register Small Squared Tower materials
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Materials/redRoof", StoneGateSetPrefix .. "_" .. _nameAsset .. "_RED_POINTED_ROOF_MATERIAL")
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Materials/blueRoof", StoneGateSetPrefix .. "_" .. _nameAsset .. "_BLUE_POINTED_ROOF_MATERIAL")
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Materials/brownRoof", StoneGateSetPrefix .. "_" .. _nameAsset .. "_BROWN_POINTED_ROOF_MATERIAL")
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Materials/greyRoof", StoneGateSetPrefix .. "_" .. _nameAsset .. "_GREY_POINTED_ROOF_MATERIAL")
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Materials/grey2Roof", StoneGateSetPrefix .. "_" .. _nameAsset .. "_GREY2_POINTED_ROOF_MATERIAL")
end

registerFbxMaterial("SmallSquaredTower", "SST")
registerFbxMaterial("OctogonalTower", "OTOWER")
registerFbxMaterial("Main", "MAIN")
registerFbxMaterial("Keep", "KEEP")
registerFbxMaterial("CircularTower", "CIRCULAR")
registerFbxMaterial("SmallCircularTower", "SCT")

function registerRoofPart(_nameFbxFile, _nameFbx, _nameAsset, _buildingPartType, _woodenCost)
    StoneGateV6:registerAssetId("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_" .. _nameAsset .. "_PREFAB")

-- Register the stone gate set decoration roof part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _woodenCost }
		}
	}
    })

    StoneGateV6:registerPrefabComponent("models/pointedRoofs/pointedRoof" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = _buildingPartType
    })
end

registerRoofPart( "SmallSquaredTower", "pointedRoof/Sst_PointedRoofB", "SST_POINTED_ROOF_B", "MAJOR", 4 )
registerRoofPart( "SmallSquaredTower", "pointedRoof/Sst_PointedRoofC", "SST_POINTED_ROOF_C", "MAJOR", 4 )
registerRoofPart( "SmallSquaredTower", "pointedRoof/Sst_PointedRoofMA", "SST_POINTED_ROOF_MA", "MAJOR", 5 )
registerRoofPart( "SmallSquaredTower", "pointedRoof/Sst_PointedRoofMB", "SST_POINTED_ROOF_MB", "MAJOR", 5 )

registerRoofPart( "OctogonalTower", "pointedRoof/OctogonalPointedRoofB", "OTOWER_POINTED_ROOF_B", "MINOR", 8 )

registerRoofPart( "Main", "pointedRoof/Main_PointedRoofA", "MAIN_POINTED_ROOF_A", "MAJOR", 10 )
registerRoofPart( "Main", "pointedRoof/Main_PointedRoofB", "MAIN_POINTED_ROOF_B", "MAJOR", 10 )
registerRoofPart( "Main", "pointedRoof/Main_PointedRoofE", "MAIN_POINTED_ROOF_E", "MAJOR", 10 )

registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofA", "KEEP_POINTED_ROOF_A", "MAJOR", 7 )
registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofB", "KEEP_POINTED_ROOF_B", "MAJOR", 7 )
registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofD", "KEEP_POINTED_ROOF_D", "MAJOR", 7 )
registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofE", "KEEP_POINTED_ROOF_E", "MAJOR", 7 )
registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofF", "KEEP_POINTED_ROOF_F", "MAJOR", 7 )
registerRoofPart( "Keep", "pointedRoof/Keep_PointedRoofG", "KEEP_POINTED_ROOF_G", "MAJOR", 7 )

registerRoofPart( "CircularTower", "pointedRoof/CircularPointedRoofB", "CIRCULAR_POINTED_ROOF_B", "MINOR", 6 )

registerRoofPart( "SmallCircularTower", "pointedRoof/SmallCircularPointedRoofB", "SCT_POINTED_ROOF_B", "MINOR", 4 )

StoneGateV6:registerAssetProcessor("models/pointedRoofs/pointedRoofPinion.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default minor decoration part registering function 
function registerDefaultMinorDecorationPart(_nameFbxFile, _nameFbx, _nameAsset, _stoneCost)
    StoneGateV6:registerAssetId("models/pointedRoofs/" .. _nameFbxFile .. ".fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB")

    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PART",
	Name = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_NAME",
	Description = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = StoneGateSetPrefix .. "_DECORATION_" .. _nameAsset .. "_PREFAB",
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _stoneCost }
		}
	}
    })

    StoneGateV6:registerPrefabComponent("models/pointedRoofs/" .. _nameFbxFile .. ".fbx/Prefab/decoration/Minor/" .. _nameFbx .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR"    })
end

registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionC", "POINTED_PINION_C", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionD", "POINTED_PINION_D", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionE", "POINTED_PINION_E", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionF", "POINTED_PINION_F", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionG", "POINTED_PINION_G", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionH", "POINTED_PINION_H", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionI", "POINTED_PINION_I", 0)
registerDefaultMinorDecorationPart("pointedRoofPinion", "PointedPinionJ", "POINTED_PINION_J", 0)


